# Generated by Django 4.2.1 on 2023-06-11 22:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("secrets", "0026_allowed_groups_users_intermediate"),
    ]

    operations = [
        migrations.AddConstraint(
            model_name="sharedsecretdata",
            constraint=models.CheckConstraint(
                check=models.Q(
                    models.Q(("group__isnull", False), ("user__isnull", True)),
                    models.Q(("group__isnull", True), ("user__isnull", False)),
                    _connector="OR",
                ),
                name="only_one_set",
            ),
        ),
    ]
