# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-13 15:44
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0013_auto_20161021_1411'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accessrequest',
            name='closed_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='access_requests_closed', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='accessrequest',
            name='requester',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='access_requests_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='accessrequest',
            name='secret',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='access_requests', to='secrets.Secret'),
        ),
        migrations.AlterField(
            model_name='secret',
            name='created_by',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='passwords_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='secret',
            name='current_revision',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='_password_current_revision', to='secrets.SecretRevision'),
        ),
        migrations.AlterField(
            model_name='secretrevision',
            name='secret',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='secrets.Secret'),
        ),
        migrations.AlterField(
            model_name='secretrevision',
            name='set_by',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='password_revisions_set', to=settings.AUTH_USER_MODEL),
        ),
    ]
