{% extends "rest_framework/base.html" %}
{% load i18n %}
{% block title %}TeamVault API{% endblock %}
{% block branding %}
<a class="navbar-brand" rel="nofollow" href="https://github.com/trehn/teamvault">
	TeamVault <span class="version">{{ version }}</span>
</a>
{% endblock %}
