# Generated by Django 4.2.1 on 2023-06-12 00:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("secrets", "0029_sharedsecretdata_granted_by"),
    ]

    operations = [
        migrations.AddField(
            model_name="sharedsecretdata",
            name="granted_on",
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
    ]
