# Generated by Django 4.2.13 on 2024-07-15 11:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0032_alter_sharedsecretdata_granted_by'),
    ]

    operations = [
        migrations.AddField(
            model_name='secretrevision',
            name='encrypted_otp_key',
            field=models.BinaryField(blank=True, null=True),
        ),
    ]
