{% extends 'secrets/secret_detail.html' %}
{% load i18n %}

{% block secret_content %}
    <div class="input-group input-group-lg">
        <input type="text" class="form-control" readonly autocomplete="off"
               placeholder="{{ secret.filename }}">
        <div class="vr mx-1"></div>
        <a href="{% url "secrets.secret-download" secret.hashid %}" class="btn btn-light">
            <i class="fa fa-download"></i> &nbsp;{% trans "Download" %} &nbsp;
        </a>
    </div>
{% endblock %}

{% block secret_attributes %}
    {% if secret.description %}
        <hr>
        <div class="row mb-3 table-responsive">
            <table class="align-middle justify-content-center secret-attributes">
                <tr>
                    <td>{% trans "Description" %}</td>
                    <td>{{ secret.description|linebreaksbr|urlize }}</td>
                </tr>
            </table>
        </div>
    {% endif %}
{% endblock %}
