# Generated by Django 4.2.1 on 2023-06-15 17:48

from django.db import migrations


def remove_inactivate_users_from_groups(apps, schema_editor):
    user_model = apps.get_model('auth', 'User')
    for user in user_model.objects.all().exclude(groups__isnull=False, is_active=True):
        user.groups.clear()


class Migration(migrations.Migration):
    dependencies = [('auth', '__latest__')]

    operations = [
        migrations.RunPython(remove_inactivate_users_from_groups),
    ]
