body, .modal-dialog-scrollable .modal-body {
  &::-webkit-scrollbar {
    width: 20px;
  }

  &::-webkit-scrollbar-track {
    background-color: transparent;
  }

  &::-webkit-scrollbar-thumb {
    background-color: var(--bs-secondary);
    border-radius: 20px;
    border: 8px solid transparent;
    background-clip: content-box;
    min-height: 50px;
  }

  &::-webkit-scrollbar-thumb:hover {
    background-color: var(--bs-gray-500);
  }
}
