# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-30 10:51
from __future__ import unicode_literals

import django.contrib.postgres.search
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0011_remove_secret_search_index'),
    ]

    operations = [
        migrations.AddField(
            model_name='secret',
            name='search_index',
            field=django.contrib.postgres.search.SearchVectorField(blank=True, null=True),
        ),
    ]
