# Generated by Django 3.2.6 on 2021-08-24 12:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0023_auto_20190822_1234'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='secret',
            name='notify_on_access_request',
        ),
        migrations.AlterField(
            model_name='secret',
            name='access_policy',
            field=models.PositiveSmallIntegerField(choices=[(1, 'discoverable'), (2, 'everyone'), (3, 'hidden')], default=1),
        ),
        migrations.DeleteModel(
            name='AccessRequest',
        ),
    ]
