# Generated by Django 4.2.3 on 2023-08-29 12:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("accounts", "0003_usersettings_avatar"),
    ]

    operations = [
        migrations.AlterField(
            model_name="usersettings",
            name="hide_deleted_secrets",
            field=models.BooleanField(
                default=True,
                help_text="Hides deleted secrets per default. Enable them in filters to see them again.",
            ),
        ),
    ]
