# Generated by Django 4.2.3 on 2024-03-05 14:15

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("audit", "0006_logentry_reason"),
    ]

    operations = [
        migrations.AlterField(
            model_name="logentry",
            name="category",
            field=models.CharField(
                choices=[
                    ("secret_read", "secret_read"),
                    ("secret_elevated_superuser_read", "secret_elevated_superuser_read"),
                    ("secret_permission_violation", "secret_permission_violation"),
                    ("secret_changed", "secret_changed"),
                    ("secret_needs_changing_reminder", "secret_needs_changing_reminder"),
                    ("secret_shared", "secret_shared"),
                    ("secret_superuser_shared", "secret_superuser_shared"),
                    ("secret_share_removed", "secret_share_removed"),
                    ("secret_superuser_share_removed", "secret_superuser_share_removed"),
                    ("secret_legacy_access_requests", "secret_legacy_access_requests"),
                    ("user_activated", "user_activated"),
                    ("user_deactivated", "user_deactivated"),
                    ("user_settings_changed", "user_settings_changed"),
                    ("share_automatically_revoked", "share_automatically_revoked"),
                    ("miscellaneous", "miscellaneous"),
                ],
                default="miscellaneous",
                max_length=64,
            ),
        ),
    ]
