{% extends "base.html" %}
{% load i18n %}
{% load static %}
{% block title %}{% trans "Dashboard" %}{% endblock %}
{% block content %}
    <div class="row justify-content-center px-3">
        <div class="col-xxl-5 col-xl-6">
            <h3>{% trans "Recently used secrets" %}</h3>
            <div class="row mt-3">
                <div class="col-12">
                    {% if recently_used_secrets %}
                        <div class="list-group list-group-hover mx-2">
                            {% for secret in recently_used_secrets %}
                                {% include "secrets/secret_row.html" %}
                            {% endfor %}
                        </div>
                    {% else %}
                        <div class="alert alert-info text-center" role="alert">
                            {% translate "You have not used any secrets recently." %}
                        </div>
                    {% endif %}
                </div>
            </div>
        </div>
        <div class="col-xxl-5 col-xl-6 mt-5 mt-xl-0">
            <h3>{% trans "Most used secrets" %}</h3>
            <div class="row mt-3">
                <div class="col-12">
                    {% if most_used_secrets %}
                        <div class="list-group list-group-hover mx-2">
                            {% for secret in most_used_secrets %}
                                {% include "secrets/secret_row.html" %}
                            {% endfor %}
                        </div>
                    {% else %}
                        <div class="alert alert-info text-center" role="alert">
                            {% translate "You have not used any secrets yet." %}
                        </div>
                    {% endif %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}
