# Generated by Django 4.2.1 on 2023-06-11 22:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("secrets", "0027_sharedsecretdata_only_one_set"),
    ]

    operations = [
        migrations.AddField(
            model_name="sharedsecretdata",
            name="grant_description",
            field=models.TextField(null=True),
        ),
        migrations.AddField(
            model_name="sharedsecretdata",
            name="granted_until",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
