<div class="bg-secondary-subtle rounded-1 d-flex px-2 align-items-center flex-row"
     style="height: 20px; min-width: 0;">
    <div class="d-inline-block">
        <span>{{ filter_item_name }}</span>
    </div>
</div>
