# Generated by Django 4.2.1 on 2023-06-11 16:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("secrets", "0024_auto_20210824_1203"),
    ]

    operations = [
        migrations.AlterField(
            model_name="secret",
            name="description",
            field=models.TextField(
                blank=True, help_text="Further information on the secret.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="secret",
            name="name",
            field=models.CharField(
                help_text="Enter a unique name for the secret", max_length=92
            ),
        ),
    ]
