<div class="col-auto me-1"><i class="fa fa-fw fa-${data.value.icon}"></i></div>
<div class="col-10 search-modal-result-content">
    <span class="search-modal-result-content-title text-truncate">
        ${data.value.name}
    </span>
    <span class="search-modal-result-content-extras text-muted">
        ${data.value.meta}
    </span>
</div>
<div class="col-1 search-modal-result-action">
    <svg width="20" height="20" viewBox="0 0 20 20">
        <g stroke="currentColor" fill="none" fill-rule="evenodd" stroke-linecap="round"
           stroke-linejoin="round">
            <path d="M18 3v4c0 2-2 4-4 4H2"></path>
            <path d="M8 17l-6-6 6-6"></path>
        </g>
    </svg>
</div>
