{% extends "base.html" %}
{% load i18n %}
{% load static %}
{% block title %}{% trans "Confirm restore" %}{% endblock %}
{% block content %}
    <div class="row justify-content-center">
        <div class="col-8 col-lg-4">
            <h1>
                {% blocktrans with name=secret.name content_type=secret.get_content_type_display %}
                    Restore {{ content_type }} '{{ name }}'?
                {% endblocktrans %}
            </h1>
            <hr>
        </div>
    </div>
    <div class="row justify-content-center">
        <div class="col-8 col-lg-4">
            <div class="alert alert-info" role="alert">
                {% blocktrans %}
                    The secret will be restored with its current permissions. Please be sure that the secret should be
                    restored and become visible to users.
                {% endblocktrans %}
            </div>
            <form role="form" method="POST" class="form-horizontal">
                {% csrf_token %}
                <a class="btn btn-light btn-lg fa-pull-left" href="{{ secret.get_absolute_url }}"><i
                        class="fa fa-angle-left"></i> &nbsp; {% trans "No, go back" %}</a>
                <button type="submit" class="btn btn-danger btn-lg fa-pull-right"><i class="fa fa-undo"></i>
                    &nbsp; {% trans "Yes, restore" %}</button>
            </form>
        </div>
    </div>
{% endblock %}
