# Generated by Django 4.2.3 on 2023-09-05 11:57

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("auth", "0012_alter_user_first_name_max_length"),
        ("accounts", "0004_alter_usersettings_hide_deleted_secrets"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="UserSettings",
            new_name="UserProfile",
        ),
    ]
